@@ -16,15 +16,40 @@ Please cite:
 
 __author__ = "DataJoint Contributors"
 __date__ = "November 7, 2020"
-__all__ = ['__author__', '__version__',
-           'config', 'conn', 'Connection',
-           'Schema', 'schema', 'VirtualModule', 'create_virtual_module',
-           'list_schemas', 'Table', 'FreeTable',
-           'Manual', 'Lookup', 'Imported', 'Computed', 'Part',
-           'Not', 'AndList', 'U', 'Diagram', 'Di', 'ERD',
-           'set_password', 'kill',
-           'MatCell', 'MatStruct', 'AttributeAdapter',
-           'errors', 'DataJointError', 'key', 'key_hash']
+__all__ = [
+    "__author__",
+    "__version__",
+    "config",
+    "conn",
+    "Connection",
+    "Schema",
+    "schema",
+    "VirtualModule",
+    "create_virtual_module",
+    "list_schemas",
+    "Table",
+    "FreeTable",
+    "Manual",
+    "Lookup",
+    "Imported",
+    "Computed",
+    "Part",
+    "Not",
+    "AndList",
+    "U",
+    "Diagram",
+    "Di",
+    "ERD",
+    "set_password",
+    "kill",
+    "MatCell",
+    "MatStruct",
+    "AttributeAdapter",
+    "errors",
+    "DataJointError",
+    "key",
+    "key_hash",
+]
 
 from .version import __version__
 from .settings import config
@@ -44,6 +69,6 @@ from . import errors
 from .errors import DataJointError
 from .migrate import migrate_dj011_external_blob_storage_to_dj012
 
-ERD = Di = Diagram                      # Aliases for Diagram
-schema = Schema                         # Aliases for Schema
-create_virtual_module = VirtualModule   # Aliases for VirtualModule
+ERD = Di = Diagram  # Aliases for Diagram
+schema = Schema  # Aliases for Schema
+create_virtual_module = VirtualModule  # Aliases for VirtualModule
