@@ -38,8 +38,16 @@ class Schema:
     It also specifies the namespace `context` in which other UserTable classes are defined.
     """
 
-    def __init__(self, schema_name=None, context=None, *, connection=None, create_schema=True,
-                 create_tables=True, add_objects=None):
+    def __init__(
+        self,
+        schema_name=None,
+        context=None,
+        *,
+        connection=None,
+        create_schema=True,
+        create_tables=True,
+        add_objects=None
+    ):
         """
         Associate database schema `schema_name`. If the schema does not exist, attempt to
         create it on the server.
@@ -71,8 +79,15 @@ class Schema:
     def is_activated(self):
         return self.database is not None
 
-    def activate(self, schema_name=None, *, connection=None, create_schema=None,
-                 create_tables=None, add_objects=None):
+    def activate(
+        self,
+        schema_name=None,
+        *,
+        connection=None,
+        create_schema=None,
+        create_tables=None,
+        add_objects=None
+    ):
         """
         Associate database schema `schema_name`. If the schema does not exist, attempt to
         create it on the server.
@@ -93,7 +108,10 @@ class Schema:
             if self.database == schema_name:  # already activated
                 return
             raise DataJointError(
-                "The schema is already activated for schema {db}.".format(db=self.database))
+                "The schema is already activated for schema {db}.".format(
+                    db=self.database
+                )
+            )
         if connection is not None:
             self.connection = connection
         if self.connection is None:
@@ -109,17 +127,23 @@ class Schema:
             if not self.create_schema or not self.database:
                 raise DataJointError(
                     "Database `{name}` has not yet been declared. "
-                    "Set argument create_schema=True to create it.".format(name=schema_name))
+                    "Set argument create_schema=True to create it.".format(
+                        name=schema_name
+                    )
+                )
             # create database
             logger.info("Creating schema `{name}`.".format(name=schema_name))
             try:
-                self.connection.query("CREATE DATABASE `{name}`".format(name=schema_name))
+                self.connection.query(
+                    "CREATE DATABASE `{name}`".format(name=schema_name)
+                )
             except AccessError:
                 raise DataJointError(
                     "Schema `{name}` does not exist and could not be created. "
-                    "Check permissions.".format(name=schema_name))
+                    "Check permissions.".format(name=schema_name)
+                )
             else:
-                self.log('created')
+                self.log("created")
         self.connection.register(self)
 
         # decorate all tables already decorated
@@ -131,7 +155,9 @@ class Schema:
     def _assert_exists(self, message=None):
         if not self.exists:
             raise DataJointError(
-                message or "Schema `{db}` has not been created.".format(db=self.database))
+                message
+                or "Schema `{db}` has not been created.".format(db=self.database)
+            )
 
     def __call__(self, cls, *, context=None):
         """
@@ -141,7 +167,9 @@ class Schema:
         """
         context = context or self.context or inspect.currentframe().f_back.f_locals
         if issubclass(cls, Part):
-            raise DataJointError('The schema decorator should not be applied to Part relations')
+            raise DataJointError(
+                "The schema decorator should not be applied to Part relations"
+            )
         if self.is_activated():
             self._decorate_master(cls, context)
         else:
@@ -153,7 +181,9 @@ class Schema:
         :param cls: the master class to process
         :param context: the class' declaration context
         """
-        self._decorate_table(cls, context=dict(context, self=cls, **{cls.__name__: cls}))
+        self._decorate_table(
+            cls, context=dict(context, self=cls, **{cls.__name__: cls})
+        )
         # Process part tables
         for part in ordered_dir(cls):
             if part[0].isupper():
@@ -161,8 +191,12 @@ class Schema:
                 if inspect.isclass(part) and issubclass(part, Part):
                     part._master = cls
                     # allow addressing master by name or keyword 'master'
-                    self._decorate_table(part, context=dict(
-                        context, master=cls, self=part, **{cls.__name__: cls}))
+                    self._decorate_table(
+                        part,
+                        context=dict(
+                            context, master=cls, self=part, **{cls.__name__: cls}
+                        ),
+                    )
 
     def _decorate_table(self, table_class, context, assert_declared=False):
         """
@@ -170,11 +204,14 @@ class Schema:
         """
         table_class.database = self.database
         table_class._connection = self.connection
-        table_class._heading = Heading(table_info=dict(
-            conn=self.connection,
-            database=self.database,
-            table_name=table_class.table_name,
-            context=context))
+        table_class._heading = Heading(
+            table_info=dict(
+                conn=self.connection,
+                database=self.database,
+                table_name=table_class.table_name,
+                context=context,
+            )
+        )
         table_class._support = [table_class.full_table_name]
         table_class.declaration_context = context
 
@@ -183,23 +220,34 @@ class Schema:
         is_declared = instance.is_declared
         if not is_declared:
             if not self.create_tables or assert_declared:
-                raise DataJointError('Table `%s` not declared' % instance.table_name)
+                raise DataJointError("Table `%s` not declared" % instance.table_name)
             instance.declare(context)
             self.connection.dependencies.clear()
         is_declared = is_declared or instance.is_declared
 
         # add table definition to the doc string
         if isinstance(table_class.definition, str):
-            table_class.__doc__ = (table_class.__doc__ or "") + "\nTable definition:\n\n" + table_class.definition
+            table_class.__doc__ = (
+                (table_class.__doc__ or "")
+                + "\nTable definition:\n\n"
+                + table_class.definition
+            )
 
         # fill values in Lookup tables from their contents property
-        if isinstance(instance, Lookup) and hasattr(instance, 'contents') and is_declared:
+        if (
+            isinstance(instance, Lookup)
+            and hasattr(instance, "contents")
+            and is_declared
+        ):
             contents = list(instance.contents)
             if len(contents) > len(instance):
                 if instance.heading.has_autoincrement:
-                    warnings.warn(('Contents has changed but cannot be inserted because '
-                                  '{table} has autoincrement.').format(
-                        table=instance.__class__.__name__))
+                    warnings.warn(
+                        (
+                            "Contents has changed but cannot be inserted because "
+                            "{table} has autoincrement."
+                        ).format(table=instance.__class__.__name__)
+                    )
                 else:
                     instance.insert(contents, skip_duplicates=True)
 
@@ -211,7 +259,7 @@ class Schema:
         return self._log
 
     def __repr__(self):
-        return 'Schema `{name}`\n'.format(name=self.database)
+        return "Schema `{name}`\n".format(name=self.database)
 
     @property
     def size_on_disk(self):
@@ -219,11 +267,16 @@ class Schema:
         :return: size of the entire schema in bytes
         """
         self._assert_exists()
-        return int(self.connection.query(
-            """
+        return int(
+            self.connection.query(
+                """
             SELECT SUM(data_length + index_length)
             FROM information_schema.tables WHERE table_schema='{db}'
-            """.format(db=self.database)).fetchone()[0])
+            """.format(
+                    db=self.database
+                )
+            ).fetchone()[0]
+        )
 
     def spawn_missing_classes(self, context=None):
         """
@@ -241,30 +294,44 @@ class Schema:
                 context = frame.f_locals
                 del frame
         tables = [
-            row[0] for row in self.connection.query('SHOW TABLES in `%s`' % self.database)
-            if lookup_class_name('`{db}`.`{tab}`'.format(db=self.database, tab=row[0]), context, 0) is None]
+            row[0]
+            for row in self.connection.query("SHOW TABLES in `%s`" % self.database)
+            if lookup_class_name(
+                "`{db}`.`{tab}`".format(db=self.database, tab=row[0]), context, 0
+            )
+            is None
+        ]
         master_classes = (Lookup, Manual, Imported, Computed)
         part_tables = []
         for table_name in tables:
             class_name = to_camel_case(table_name)
             if class_name not in context:
                 try:
-                    cls = next(cls for cls in master_classes if re.fullmatch(cls.tier_regexp, table_name))
+                    cls = next(
+                        cls
+                        for cls in master_classes
+                        if re.fullmatch(cls.tier_regexp, table_name)
+                    )
                 except StopIteration:
                     if re.fullmatch(Part.tier_regexp, table_name):
                         part_tables.append(table_name)
                 else:
                     # declare and decorate master relation classes
-                    context[class_name] = self(type(class_name, (cls,), dict()), context=context)
+                    context[class_name] = self(
+                        type(class_name, (cls,), dict()), context=context
+                    )
 
         # attach parts to masters
         for table_name in part_tables:
             groups = re.fullmatch(Part.tier_regexp, table_name).groupdict()
-            class_name = to_camel_case(groups['part'])
+            class_name = to_camel_case(groups["part"])
             try:
-                master_class = context[to_camel_case(groups['master'])]
+                master_class = context[to_camel_case(groups["master"])]
             except KeyError:
-                raise DataJointError('The table %s does not follow DataJoint naming conventions' % table_name)
+                raise DataJointError(
+                    "The table %s does not follow DataJoint naming conventions"
+                    % table_name
+                )
             part_class = type(class_name, (Part,), dict(definition=...))
             part_class._master = master_class
             self._decorate_table(part_class, context=context, assert_declared=True)
@@ -275,19 +342,34 @@ class Schema:
         Drop the associated schema if it exists
         """
         if not self.exists:
-            logger.info("Schema named `{database}` does not exist. Doing nothing.".format(
-                database=self.database))
-        elif (not config['safemode'] or
-              force or
-              user_choice("Proceed to delete entire schema `%s`?" % self.database, default='no') == 'yes'):
+            logger.info(
+                "Schema named `{database}` does not exist. Doing nothing.".format(
+                    database=self.database
+                )
+            )
+        elif (
+            not config["safemode"]
+            or force
+            or user_choice(
+                "Proceed to delete entire schema `%s`?" % self.database, default="no"
+            )
+            == "yes"
+        ):
             logger.info("Dropping `{database}`.".format(database=self.database))
             try:
-                self.connection.query("DROP DATABASE `{database}`".format(database=self.database))
-                logger.info("Schema `{database}` was dropped successfully.".format(database=self.database))
+                self.connection.query(
+                    "DROP DATABASE `{database}`".format(database=self.database)
+                )
+                logger.info(
+                    "Schema `{database}` was dropped successfully.".format(
+                        database=self.database
+                    )
+                )
             except AccessError:
                 raise AccessError(
                     "An attempt to drop schema `{database}` "
-                    "has failed. Check permissions.".format(database=self.database))
+                    "has failed. Check permissions.".format(database=self.database)
+                )
 
     @property
     def exists(self):
@@ -296,10 +378,13 @@ class Schema:
         """
         if self.database is None:
             raise DataJointError("Schema must be activated first.")
-        return bool(self.connection.query(
-            "SELECT schema_name "
-            "FROM information_schema.schemata "
-            "WHERE schema_name = '{database}'".format(database=self.database)).rowcount)
+        return bool(
+            self.connection.query(
+                "SELECT schema_name "
+                "FROM information_schema.schemata "
+                "WHERE schema_name = '{database}'".format(database=self.database)
+            ).rowcount
+        )
 
     @property
     def jobs(self):
@@ -326,44 +411,61 @@ class Schema:
         self._assert_exists()
         module_count = itertools.count()
         # add virtual modules for referenced modules with names vmod0, vmod1, ...
-        module_lookup = collections.defaultdict(lambda: 'vmod' + str(next(module_count)))
+        module_lookup = collections.defaultdict(
+            lambda: "vmod" + str(next(module_count))
+        )
         db = self.database
 
         def make_class_definition(table):
             tier = _get_tier(table).__name__
-            class_name = table.split('.')[1].strip('`')
-            indent = ''
-            if tier == 'Part':
-                class_name = class_name.split('__')[-1]
-                indent += '    '
+            class_name = table.split(".")[1].strip("`")
+            indent = ""
+            if tier == "Part":
+                class_name = class_name.split("__")[-1]
+                indent += "    "
             class_name = to_camel_case(class_name)
 
             def replace(s):
                 d, tabs = s.group(1), s.group(2)
-                return ('' if d == db else (module_lookup[d]+'.')) + '.'.join(
-                    to_camel_case(tab) for tab in tabs.lstrip('__').split('__'))
+                return ("" if d == db else (module_lookup[d] + ".")) + ".".join(
+                    to_camel_case(tab) for tab in tabs.lstrip("__").split("__")
+                )
 
-            return ('' if tier == 'Part' else '\n@schema\n') + (
-                '{indent}class {class_name}(dj.{tier}):\n'
+            return ("" if tier == "Part" else "\n@schema\n") + (
+                "{indent}class {class_name}(dj.{tier}):\n"
                 '{indent}    definition = """\n'
-                '{indent}    {defi}"""').format(
-                    class_name=class_name,
-                    indent=indent,
-                    tier=tier,
-                    defi=re.sub(r'`([^`]+)`.`([^`]+)`', replace,
-                                FreeTable(self.connection, table).describe(printout=False)
-                                ).replace('\n', '\n    ' + indent))
+                '{indent}    {defi}"""'
+            ).format(
+                class_name=class_name,
+                indent=indent,
+                tier=tier,
+                defi=re.sub(
+                    r"`([^`]+)`.`([^`]+)`",
+                    replace,
+                    FreeTable(self.connection, table).describe(printout=False),
+                ).replace("\n", "\n    " + indent),
+            )
 
         diagram = Diagram(self)
-        body = '\n\n'.join(make_class_definition(table) for table in diagram.topological_sort())
-        python_code = '\n\n'.join((
-            '"""This module was auto-generated by datajoint from an existing schema"""',
-            "import datajoint as dj\n\nschema = dj.Schema('{db}')".format(db=db),
-            '\n'.join("{module} = dj.VirtualModule('{module}', '{schema_name}')".format(module=v, schema_name=k)
-                      for k, v in module_lookup.items()), body))
+        body = "\n\n".join(
+            make_class_definition(table) for table in diagram.topological_sort()
+        )
+        python_code = "\n\n".join(
+            (
+                '"""This module was auto-generated by datajoint from an existing schema"""',
+                "import datajoint as dj\n\nschema = dj.Schema('{db}')".format(db=db),
+                "\n".join(
+                    "{module} = dj.VirtualModule('{module}', '{schema_name}')".format(
+                        module=v, schema_name=k
+                    )
+                    for k, v in module_lookup.items()
+                ),
+                body,
+            )
+        )
         if python_filename is None:
             return python_code
-        with open(python_filename, 'wt') as f:
+        with open(python_filename, "wt") as f:
             f.write(python_code)
 
     def list_tables(self):
@@ -372,9 +474,14 @@ class Schema:
         as ~logs and ~job
         :return: A list of table names from the database schema.
         """
-        return [t for d, t in (full_t.replace('`', '').split('.')
-                               for full_t in Diagram(self).topological_sort())
-                if d == self.database]
+        return [
+            t
+            for d, t in (
+                full_t.replace("`", "").split(".")
+                for full_t in Diagram(self).topological_sort()
+            )
+            if d == self.database
+        ]
 
 
 class VirtualModule(types.ModuleType):
@@ -382,8 +489,17 @@ class VirtualModule(types.ModuleType):
     A virtual module imitates a Python module representing a DataJoint schema from table definitions in the database.
     It declares the schema objects and a class for each table.
     """
-    def __init__(self, module_name, schema_name, *, create_schema=False,
-                 create_tables=False, connection=None, add_objects=None):
+
+    def __init__(
+        self,
+        module_name,
+        schema_name,
+        *,
+        create_schema=False,
+        create_tables=False,
+        connection=None,
+        add_objects=None
+    ):
         """
         Creates a python module with the given name from the name of a schema on the server and
         automatically adds classes to it corresponding to the tables in the schema.
@@ -396,11 +512,15 @@ class VirtualModule(types.ModuleType):
         :return: the python module containing classes from the schema object and the table classes
         """
         super(VirtualModule, self).__init__(name=module_name)
-        _schema = Schema(schema_name, create_schema=create_schema,
-                         create_tables=create_tables, connection=connection)
+        _schema = Schema(
+            schema_name,
+            create_schema=create_schema,
+            create_tables=create_tables,
+            connection=connection,
+        )
         if add_objects:
             self.__dict__.update(add_objects)
-        self.__dict__['schema'] = _schema
+        self.__dict__["schema"] = _schema
         _schema.spawn_missing_classes(context=self.__dict__)
 
 
@@ -409,7 +529,11 @@ def list_schemas(connection=None):
     :param connection: a dj.Connection object
     :return: list of all accessible schemas on the server
     """
-    return [r[0] for r in (connection or conn()).query(
-        'SELECT schema_name '
-        'FROM information_schema.schemata '
-        'WHERE schema_name <> "information_schema"')]
+    return [
+        r[0]
+        for r in (connection or conn()).query(
+            "SELECT schema_name "
+            "FROM information_schema.schemata "
+            'WHERE schema_name <> "information_schema"'
+        )
+    ]
