@@ -23,10 +23,12 @@ def user_choice(prompt, choices=("yes", "no"), default=None):
     :return: the user's choice
     """
     assert default is None or default in choices
-    choice_list = ', '.join((choice.title() if choice == default else choice for choice in choices))
+    choice_list = ", ".join(
+        (choice.title() if choice == default else choice for choice in choices)
+    )
     response = None
     while response not in choices:
-        response = input(prompt + ' [' + choice_list + ']: ')
+        response = input(prompt + " [" + choice_list + "]: ")
         response = response.lower() if response else default
     return response
 
@@ -46,8 +48,8 @@ def get_master(full_table_name: str) -> str:
     :return: Supposed master full table name or empty string if not a part table name.
     :rtype: str
     """
-    match = re.match(r'(?P<master>`\w+`.`\w+)__(?P<part>\w+)`', full_table_name)
-    return match['master'] + '`' if match else ''
+    match = re.match(r"(?P<master>`\w+`.`\w+)__(?P<part>\w+)`", full_table_name)
+    return match["master"] + "`" if match else ""
 
 
 def to_camel_case(s):
@@ -62,7 +64,7 @@ def to_camel_case(s):
     def to_upper(match):
         return match.group(0)[-1].upper()
 
-    return re.sub(r'(^|[_\W])+[a-zA-Z]', to_upper, s)
+    return re.sub(r"(^|[_\W])+[a-zA-Z]", to_upper, s)
 
 
 def from_camel_case(s):
@@ -75,12 +77,13 @@ def from_camel_case(s):
     """
 
     def convert(match):
-        return ('_' if match.groups()[0] else '') + match.group(0).lower()
+        return ("_" if match.groups()[0] else "") + match.group(0).lower()
 
-    if not re.match(r'[A-Z][a-zA-Z0-9]*', s):
+    if not re.match(r"[A-Z][a-zA-Z0-9]*", s):
         raise DataJointError(
-            'ClassName must be alphanumeric in CamelCase, begin with a capital letter')
-    return re.sub(r'(\B[A-Z])|(\b[A-Z])', convert, s)
+            "ClassName must be alphanumeric in CamelCase, begin with a capital letter"
+        )
+    return re.sub(r"(\B[A-Z])|(\b[A-Z])", convert, s)
 
 
 def safe_write(filepath, blob):
@@ -92,7 +95,7 @@ def safe_write(filepath, blob):
     filepath = Path(filepath)
     if not filepath.is_file():
         filepath.parent.mkdir(parents=True, exist_ok=True)
-        temp_file = filepath.with_suffix(filepath.suffix + '.saving')
+        temp_file = filepath.with_suffix(filepath.suffix + ".saving")
         temp_file.write_bytes(blob)
         temp_file.rename(filepath)
 
@@ -104,7 +107,7 @@ def safe_copy(src, dest, overwrite=False):
     src, dest = Path(src), Path(dest)
     if not (dest.exists() and src.samefile(dest)) and (overwrite or not dest.is_file()):
         dest.parent.mkdir(parents=True, exist_ok=True)
-        temp_file = dest.with_suffix(dest.suffix + '.copying')
+        temp_file = dest.with_suffix(dest.suffix + ".copying")
         shutil.copyfile(str(src), str(temp_file))
         temp_file.rename(dest)
 
@@ -113,16 +116,16 @@ def parse_sql(filepath):
     """
     yield SQL statements from an SQL file
     """
-    delimiter = ';'
+    delimiter = ";"
     statement = []
-    with Path(filepath).open('rt') as f:
+    with Path(filepath).open("rt") as f:
         for line in f:
             line = line.strip()
-            if not line.startswith('--') and len(line) > 1:
-                if line.startswith('delimiter'):
+            if not line.startswith("--") and len(line) > 1:
+                if line.startswith("delimiter"):
                     delimiter = line.split()[1]
                 else:
                     statement.append(line)
                     if line.endswith(delimiter):
-                        yield ' '.join(statement)
+                        yield " ".join(statement)
                         statement = []
